<template>
    <ele-page flex-table>
        <book-search @search="reload" />

        <common-table
            ref="pageRef"
            :pageConfig="pageConfig"
            :columns="columns"
            :tools="false"
        >
            <template #toolbar>
                <el-radio-group
                    @change="handleStatusChange"
                    v-model="searchType"
                >
                    <el-radio-button label="全部" value="0" />
                    <el-radio-button
                        label="已加入回收书单（正在回收）"
                        value="1"
                    />
                    <el-radio-button
                        label="已加入回收书单（暂停回收）"
                        value="2"
                    />
                    <el-radio-button label="未加入回收书单" value="3" />
                    <el-radio-button label="黑名单" value="4" />
                </el-radio-group>

                <span class="ml-8"></span>
                <el-button
                    type="warning"
                    plain
                    v-permission="'recycle:booklist:batchRemoveBooklist'"
                    @click="handleOptBooklist('remove')"
                    v-if="['0', '1', '2'].includes(searchType)"
                >
                    移除回收书单
                </el-button>
                <el-button
                    type="success"
                    plain
                    v-permission="'recycle:booklist:batchAddBooklist'"
                    @click="handleOptBooklist('add')"
                    v-if="['3', '4'].includes(searchType)"
                >
                    加入回收书单
                </el-button>
                <el-button
                    type="warning"
                    plain
                    v-permission="'recycle:booklist:batchRemoveBlacklist'"
                    @click="handleOptBlacklist('remove')"
                    v-if="searchType === '4'"
                >
                    移除黑名单
                </el-button>
                <el-button
                    type="danger"
                    plain
                    v-permission="'recycle:booklist:batchAddBlacklist'"
                    @click="handleOptBlacklist('add')"
                    v-if="searchType !== '4'"
                >
                    加黑名单
                </el-button>

                <el-button
                    type="warning"
                    plain
                    v-permission="'recycle:booklist:batchPauseRecycle'"
                    @click="handleOptRecycle('pause')"
                    v-if="searchType === '1'"
                >
                    暂停回收
                </el-button>
                <el-button
                    type="warning"
                    plain
                    v-permission="'recycle:booklist:batchStartRecycle'"
                    @click="handleOptRecycle('start')"
                    v-if="['0', '2'].includes(searchType)"
                >
                    开启回收
                </el-button>
                <el-button
                    type="primary"
                    plain
                    v-permission="'recycle:booklist:batchAddDiscount'"
                    @click="handleAddDiscount()"
                    v-if="searchType === '3'"
                >
                    指定折扣加回收书单
                </el-button>
                <el-button
                    type="success"
                    plain
                    v-permission="'recycle:booklist:batchAddSocial'"
                    @click="handleOptType(1)"
                >
                    加社科库
                </el-button>
                <el-button
                    type="primary"
                    plain
                    v-permission="'recycle:booklist:batchAddTeach'"
                    @click="handleOptType(2)"
                >
                    加教材库
                </el-button>
            </template>

            <template #cover="{ row }">
                <el-image
                    style="width: 90px; height: 120px; border-radius: 4px"
                    fit="cover"
                    :src="row.cover"
                    :preview-src-list="[row.cover]"
                    :initial-index="0"
                    preview-teleported
                />
            </template>
            <template #baseInfo="{ row }">
                <book-info :row="row" @refresh="reload" />
            </template>
            <template #stock="{ row }">
                <book-stock :row="row" />
            </template>

            <template #action="{ row }">
                <el-button
                    type="primary"
                    link
                    v-permission="'recycle:booklist:updateBook'"
                    @click="handleUpdateBook(row)"
                >
                    [编辑]
                </el-button>
                <el-button
                    color="#192bbe"
                    plain
                    link
                    v-permission="'recycle:booklist:setParams'"
                    @click="handleSetParams(row)"
                >
                    [设置独立参数]
                </el-button>
                <el-button
                    type="success"
                    link
                    v-permission="'recycle:booklist:removeBlacklist'"
                    @click="handleOptBlacklist('remove', row)"
                    v-if="row.bookStatus == 3"
                >
                    [移除黑名单]
                </el-button>
                <el-button
                    type="warning"
                    link
                    v-permission="'recycle:booklist:addBlacklist'"
                    @click="handleOptBlacklist('add', row)"
                    v-if="row.bookStatus == 1 || row.bookStatus == 2"
                >
                    [加入黑名单]
                </el-button>
                <el-button
                    type="danger"
                    link
                    v-permission="'recycle:booklist:pauseRecycle'"
                    @click="handleOptRecycle('pause', row)"
                    v-if="row.recycleStatus == 1"
                >
                    [暂停回收]
                </el-button>
                <el-button
                    type="success"
                    link
                    v-permission="'recycle:booklist:startRecycle'"
                    @click="handleOptRecycle('start', row)"
                    v-else
                >
                    [开启回收]
                </el-button>
                <el-button
                    type="success"
                    link
                    v-permission="'recycle:booklist:removeBooklist'"
                    @click="handleOptBooklist('remove', row)"
                    v-if="row.bookStatus == 2"
                >
                    [移除回收书单]
                </el-button>
                <el-button
                    type="danger"
                    link
                    v-permission="'recycle:booklist:addBooklist'"
                    @click="handleOptBooklist('add', row)"
                    v-if="row.bookStatus == 1"
                >
                    [加入回收书单]
                </el-button>
            </template>
        </common-table>

        <books-edit ref="editRef" />
        <set-params ref="paramsRef" />
        <add-discount ref="discountRef" @refresh="reload" />
        <order-blacklist ref="blacklistRef" @refresh="reload" />
    </ele-page>
</template>

<script setup>
    import { ref, reactive } from 'vue';
    import CommonTable from '@/components/CommonPage/CommonTable.vue';
    import booksEdit from '@/views/data/books/components/books-edit.vue';
    import bookSearch from '@/views/recycle/components/book-search.vue';
    import bookInfo from '@/views/recycle/components/book-info.vue';
    import bookStock from '@/views/recycle/components/book-stock.vue';
    import setParams from '@/views/recycle/components/set-params.vue';
    import addDiscount from '@/views/recycle/components/add-discount.vue';
    import orderBlacklist from '@/views/recycleOrder/detail/order-blacklist.vue';
    import { useBookOperation } from '@/utils/use-book-operation';

    defineOptions({ name: 'RecycleBooklist' });

    const searchType = ref('0');
    function handleStatusChange(value) {
        searchType.value = value;
        pageConfig.params.searchType = value;
        reload();
    }

    /** 表格列配置 */
    const columns = ref([
        {
            type: 'selection',
            columnKey: 'selection',
            width: 50,
            align: 'center',
            fixed: 'left'
        },
        {
            label: '图片',
            prop: 'cover',
            width: 120,
            slot: 'cover'
        },
        {
            label: '信息',
            prop: 'baseInfo',
            width: 500,
            slot: 'baseInfo'
        },
        {
            label: '回收折扣',
            minWidth: 100,
            prop: 'recycleDiscount',
            sortable: true,
            columnKey: '4'
        },
        {
            label: '回收价格',
            prop: 'recyclePrice',
            sortable: true,
            columnKey: '5',
            minWidth: 100
        },
        {
            label: '最大回收量',
            minWidth: 120,
            prop: 'recycleMax',
            sortable: true,
            columnKey: '6'
        },
        {
            label: '总回收数量',
            minWidth: 120,
            prop: 'recycleTotalNum',
            sortable: true,
            columnKey: '2'
        },
        {
            label: '当前剩余回收量',
            minWidth: 140,
            prop: 'restRecycleNum',
            sortable: true,
            columnKey: '7'
        },
        {
            label: '销量',
            prop: 'salesNum',
            sortable: true,
            columnKey: '8'
        },
        {
            label: '库存',
            prop: 'stockTotalNum',
            sortable: true,
            columnKey: '9',
            slot: 'stock',
            minWidth: 100
        },
        {
            columnKey: 'action',
            label: '操作',
            width: 150,
            slot: 'action',
            fixed: 'right'
        }
    ]);

    /** 页面组件实例 */
    const pageRef = ref(null);

    const pageConfig = reactive({
        pageUrl: '/book/bookRecycleInfo/pageList',
        fileName: '回收书单管理',
        cacheKey: 'recycleBooklistTable',
        rowKey: 'isbn',
        params: {
            searchType: '0'
        }
    });

    //刷新表格
    function reload(where) {
        pageRef.value?.reload(where);
    }

    //编辑
    const editRef = ref(null);
    function handleUpdateBook(row) {
        let params = {
            id: row.bookId
        };
        editRef.value?.handleOpen(params);
    }

    // 使用图书操作混入
    const {
        blacklistRef,
        discountRef,
        paramsRef,
        handleOptBooklist,
        handleOptBlacklist,
        handleOptRecycle,
        handleOptType,
        handleAddDiscount,
        handleSetParams
    } = useBookOperation(pageRef);
</script>
